# FICTURE

2025-05: we implemented [a new version](https://github.com/Yichen-Si/punkst) in a c++ command line tool that is substantially more efficiency and (hopefully) easier to use. If you are interested in applying FICTURE to large datasets we would love to have you try it out.

---

FICTURE: Scalable segmentation-free analysis of sub-micron resolution spatial transcriptomics

Install
```
pip install ficture
```

Documentation [https://seqscope.github.io/ficture/](https://seqscope.github.io/ficture/)

[Paper](https://www.nature.com/articles/s41592-024-02415-2) (Real data results in the preprint are [available on Zenodo](https://zenodo.org/records/10070621))

For a brief introduction, see [slides used for AGBT talk](https://tinyurl.com/3w5xjesj)
